@@ -24,8 +24,7 @@ failures = test_runner.run_tests([
     'djangoldp.tests.tests_sources',
     'djangoldp.tests.tests_pagination',
     'djangoldp.tests.tests_inbox',
-    'djangoldp.tests.tests_backlinks_service',
-    # 'djangoldp.tests.tests_temp'
+    'djangoldp.tests.tests_backlinks_service'
 
 ])
 if failures:
